"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.endpointAdapterFactory = void 0;
const x_deep_merge_1 = require("@empathyco/x-deep-merge");
const fetch_http_client_1 = require("../http-clients/fetch.http-client");
const identity_mapper_1 = require("../mappers/identity.mapper");
const interpolate_1 = require("../utils/interpolate");
/**
 * Factory to create {@link ExtendableEndpointAdapter | endpoint adapters} with the given
 * {@link EndpointAdapterOptions | options}.
 *
 * @param options - The {@link EndpointAdapterOptions | options} to create a new
 * {@link ExtendableEndpointAdapter} with.
 *
 * @returns A brand new {@link ExtendableEndpointAdapter} object.
 * @public
 */
const endpointAdapterFactory = (options) => {
    const endpointAdapter = (request, { endpoint: requestEndpoint, ...requestOptions } = {}) => {
        const { endpoint: rawEndpoint, httpClient = fetch_http_client_1.fetchHttpClient, requestMapper = identity_mapper_1.identityMapper, responseMapper = identity_mapper_1.identityMapper, defaultRequestOptions = {} } = options;
        const endpoint = getEndpoint(requestEndpoint !== null && requestEndpoint !== void 0 ? requestEndpoint : rawEndpoint, request);
        const requestParameters = requestMapper(request, { endpoint });
        return httpClient(endpoint, (0, x_deep_merge_1.deepMerge)({}, defaultRequestOptions, requestOptions, { parameters: requestParameters })).then(response => responseMapper(response, { endpoint, requestParameters }));
    };
    endpointAdapter.extends = (extendedOptions) => (0, exports.endpointAdapterFactory)({
        ...options,
        ...extendedOptions
    });
    return endpointAdapter;
};
exports.endpointAdapterFactory = endpointAdapterFactory;
/**
 * Returns an endpoint.
 *
 * @param endpoint - The endpoint to process.
 * @param request - The request object.
 *
 * @returns The endpoint.
 * @internal
 */
function getEndpoint(endpoint, request) {
    if (!endpoint) {
        throw Error('Tried to make a request without an endpoint');
    }
    return typeof endpoint === 'function'
        ? endpoint(request, {})
        : (0, interpolate_1.interpolate)(endpoint, request);
}
//# sourceMappingURL=endpoint-adapter.factory.js.map